==> jquery-toastmessage-plugin-0.2.7.tgz: jquery-toastmessage-plugin/README.md <==
# Installation
> `npm install --save @types/jquery-toastmessage-plugin`

# Summary
This package contains type definitions for jquery-toastmessage-plugin (https://github.com/akquinet/jquery-toastmessage-plugin).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-toastmessage-plugin.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-toastmessage-plugin/index.d.ts)
````ts
// Type definitions for non-npm package jquery-toastmessage-plugin 0.2
// Project: https://github.com/akquinet/jquery-toastmessage-plugin
// Definitions by: Joe Skeen <https://github.com/joeskeen>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped
// TypeScript Version: 2.3

/// <reference types="jquery" />

interface JQuery {
    toastmessage: JQueryToastmessage.ToastmessageStatic;
}

/** jQuery Toastmessage (http://akquinet.github.io/jquery-toastmessage-plugin/) */
declare namespace JQueryToastmessage {
    interface ToastmessageStatic {
        /* shows a toast message of the specified type */
        (command: ShowToastCommand, message: string): JQuery;
        /** shows a custom toast */
        (command: "showToast", toastOpts: ToastOptions): JQuery;
        /** removes the specified toast and returns it */
        (command: "removeToast", toast: JQuery, closeOpts?: ToastOptions): void;
        /** configures the default toast options */
        (toastOpts: ToastOptions): void;
    }

    type ShowToastCommand = "showNoticeToast" | "showSuccessToast" | "showWarningToast" | "showErrorToast";
    type ToastType = "notice" | "warning" | "error" | "success";
    type ToastPosition = "top-left" | "top-center" | "top-right" | "middle-left" | "middle-center" | "middle-right";

    interface ToastOptions {
        /** in effect duration in miliseconds @default 600 */
        inEffectDuration?: number | undefined;
        /**
         * time in miliseconds before the item has to disappear @default 3000
         */
        stayTime?: number | undefined;
        /** content of the item @default '' */
        text?: string | undefined;
        /** should the toast item sticky or not? @default false */
        sticky?: boolean | undefined;
        /** the type of toast @default 'notice' */
        type?: ToastType | undefined;
        /**
         * Position of the toast container holding different toast.
         * Position can be set only once at the very first call,
         * changing the position after the first call does nothing
         * @default 'top-right'
         */
        position?: ToastPosition | undefined;
        /**
         * text which will be shown as close button,
         * set to '' when you want to introduce an image via css
         * @default ''
         */
        closeText?: string | undefined;
        /** callback function when the toastmessage is closed @default null */
        close?(): void;
    }
}

````

### Additional Details
 * Last updated: Fri, 15 Sep 2023 20:36:37 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)
 * Global values: none

# Credits
These definitions were written by [Joe Skeen](https://github.com/joeskeen).

==> jquery-toastmessage-plugin-0.2.8.tgz: jquery-toastmessage-plugin/README.md <==
# Installation
> `npm install --save @types/jquery-toastmessage-plugin`

# Summary
This package contains type definitions for jquery-toastmessage-plugin (https://github.com/akquinet/jquery-toastmessage-plugin).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-toastmessage-plugin.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/jquery-toastmessage-plugin/index.d.ts)
````ts
/// <reference types="jquery" />

interface JQuery {
    toastmessage: JQueryToastmessage.ToastmessageStatic;
}

/** jQuery Toastmessage (http://akquinet.github.io/jquery-toastmessage-plugin/) */
declare namespace JQueryToastmessage {
    interface ToastmessageStatic {
        /* shows a toast message of the specified type */
        (command: ShowToastCommand, message: string): JQuery;
        /** shows a custom toast */
        (command: "showToast", toastOpts: ToastOptions): JQuery;
        /** removes the specified toast and returns it */
        (command: "removeToast", toast: JQuery, closeOpts?: ToastOptions): void;
        /** configures the default toast options */
        (toastOpts: ToastOptions): void;
    }

    type ShowToastCommand = "showNoticeToast" | "showSuccessToast" | "showWarningToast" | "showErrorToast";
    type ToastType = "notice" | "warning" | "error" | "success";
    type ToastPosition = "top-left" | "top-center" | "top-right" | "middle-left" | "middle-center" | "middle-right";

    interface ToastOptions {
        /** in effect duration in miliseconds @default 600 */
        inEffectDuration?: number | undefined;
        /**
         * time in miliseconds before the item has to disappear @default 3000
         */
        stayTime?: number | undefined;
        /** content of the item @default '' */
        text?: string | undefined;
        /** should the toast item sticky or not? @default false */
        sticky?: boolean | undefined;
        /** the type of toast @default 'notice' */
        type?: ToastType | undefined;
        /**
         * Position of the toast container holding different toast.
         * Position can be set only once at the very first call,
         * changing the position after the first call does nothing
         * @default 'top-right'
         */
        position?: ToastPosition | undefined;
        /**
         * text which will be shown as close button,
         * set to '' when you want to introduce an image via css
         * @default ''
         */
        closeText?: string | undefined;
        /** callback function when the toastmessage is closed @default null */
        close?(): void;
    }
}

````

### Additional Details
 * Last updated: Wed, 18 Oct 2023 05:47:07 GMT
 * Dependencies: [@types/jquery](https://npmjs.com/package/@types/jquery)

# Credits
These definitions were written by [Joe Skeen](https://github.com/joeskeen).
